@@ -23,9 +23,16 @@ The long form message about the error.
 
 =cut
 
+use overload '""' => 'as_string';
+
 has 'code'      => ( is => 'ro', isa => 'Str', required => 1 );
 has 'message'   => ( is => 'ro', isa => 'Str', required => 1 );
 
+sub as_string {
+  my $self = shift;
+  return '['.$self->code.'] '.$self->message;
+}
+
 __PACKAGE__->meta->make_immutable();
 
 =back
@@ -42,4 +49,4 @@ under the same terms as Perl itself.
 =cut
 
 no Moose;
-1;
\ No newline at end of file
+1;
